==> bootstrap-core-1.0.94-test-sources.jar: com/turbospaces/common/CompletableRequestReplyMapperTest.java <==
package com.turbospaces.common;

import java.time.Duration;
import java.util.concurrent.Callable;
import java.util.concurrent.CountDownLatch;

import org.apache.commons.lang3.RandomStringUtils;
import org.apache.commons.lang3.exception.ExceptionUtils;
import org.awaitility.Awaitility;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.util.concurrent.FluentFuture;
import com.google.common.util.concurrent.FutureCallback;
import com.google.common.util.concurrent.ListenableFuture;
import com.google.common.util.concurrent.MoreExecutors;

public class CompletableRequestReplyMapperTest {
    Logger logger = LoggerFactory.getLogger(getClass());
    CompletableRequestReplyMapper<String, Long> mapper;

    @BeforeEach
    public void before() {
        mapper = new CompletableRequestReplyMapper<>();
        mapper.afterPropertiesSet();
    }
    @AfterEach
    public void after() throws Exception {
        mapper.destroy();
    }
    @Test
    public void works() throws InterruptedException {
        String key = RandomStringUtils.randomAlphanumeric(4);
        CountDownLatch l = new CountDownLatch(1);
        ListenableFuture<Long> f = mapper.acquire(key, Duration.ofSeconds(15));
        f.addListener(new Runnable() {
            @Override
            public void run() {
                l.countDown();
            }
        }, MoreExecutors.directExecutor());
        Assertions.assertEquals(1, mapper.pendingCount());
        mapper.complete(key, System.currentTimeMillis());
        l.await();
        Assertions.assertEquals(0, mapper.pendingCount());
    }
    @Test
    public void timeoutRaw() throws InterruptedException {
        String key = RandomStringUtils.randomAlphanumeric(4);
        CountDownLatch l = new CountDownLatch(1);
        ListenableFuture<Long> f = mapper.acquire(key, Duration.ofMillis(1));
        f.addListener(new Runnable() {
            @Override
            public void run() {
                try {
                    f.get();
                } catch (Exception err) {
                    RequestReplyTimeout timeout = (RequestReplyTimeout) err.getCause();
                    logger.error(timeout.getMessage(), timeout);
                    l.countDown();
                }
            }
        }, MoreExecutors.directExecutor());
        l.await();

        Awaitility
                .waitAtMost(Duration.ofSeconds(1))
                .until(new Callable<Boolean>() {
                    @Override
                    public Boolean call() throws Exception {
                        return mapper.pendingCount() == 0;
                    }
                });
    }
    @Test
    public void timeoutFluent() throws InterruptedException {
        String key = RandomStringUtils.randomAlphanumeric(4);
        CountDownLatch l = new CountDownLatch(1);
        FluentFuture<Long> f = FluentFuture.from(mapper.acquire(key, Duration.ofMillis(1)));
        f.addCallback(new FutureCallback<Long>() {
            @Override
            public void onSuccess(Long result) {

            }
            @Override
            public void onFailure(Throwable t) {
                RequestReplyTimeout timeout = (RequestReplyTimeout) ExceptionUtils.getRootCause(t);
                logger.error(timeout.getMessage(), timeout);
                l.countDown();
            }
        }, mapper);
        l.await();

        Awaitility
                .waitAtMost(Duration.ofSeconds(1))
                .until(new Callable<Boolean>() {
                    @Override
                    public Boolean call() throws Exception {
                        return mapper.pendingCount() == 0;
                    }
                });
    }
    @Test
    public void exceptionally() throws InterruptedException {
        String key = RandomStringUtils.randomAlphanumeric(4);
        CountDownLatch l = new CountDownLatch(1);
        FluentFuture<Long> f = FluentFuture.from(mapper.acquire(key, Duration.ofMinutes(1)));
        f.addCallback(new FutureCallback<Long>() {
            @Override
            public void onSuccess(Long result) {

            }
            @Override
            public void onFailure(Throwable t) {
                l.countDown();
            }
        }, mapper);

        mapper.completeExceptionally(key, new IllegalStateException());
        l.await();

        Awaitility
                .waitAtMost(Duration.ofSeconds(1))
                .until(new Callable<Boolean>() {
                    @Override
                    public Boolean call() throws Exception {
                        return mapper.pendingCount() == 0;
                    }
                });
    }
}

==> bootstrap-core-1.0.122-test-sources.jar: com/turbospaces/common/CompletableRequestReplyMapperTest.java <==
package com.turbospaces.common;

import java.time.Duration;
import java.util.concurrent.Callable;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.TimeUnit;

import org.apache.commons.lang3.RandomStringUtils;
import org.apache.commons.lang3.exception.ExceptionUtils;
import org.awaitility.Awaitility;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.util.concurrent.FluentFuture;
import com.google.common.util.concurrent.FutureCallback;
import com.google.common.util.concurrent.ListenableFuture;
import com.google.common.util.concurrent.MoreExecutors;
import com.turbospaces.rpc.CompletableRequestReplyMapper;
import com.turbospaces.rpc.RequestReplyTimeout;

public class CompletableRequestReplyMapperTest {
    Logger logger = LoggerFactory.getLogger(getClass());
    CompletableRequestReplyMapper<String, Long> mapper;

    @BeforeEach
    public void before() {
        mapper = new CompletableRequestReplyMapper<>();
        mapper.afterPropertiesSet();
    }
    @AfterEach
    public void after() throws Exception {
        mapper.destroy();
    }
    @Test
    public void works() throws InterruptedException {
        String key = RandomStringUtils.randomAlphanumeric(4);
        CountDownLatch l = new CountDownLatch(1);
        ListenableFuture<Long> f = mapper.acquire(key, Duration.ofSeconds(15));
        f.addListener(new Runnable() {
            @Override
            public void run() {
                l.countDown();
            }
        }, MoreExecutors.directExecutor());
        Assertions.assertEquals(1, mapper.pendingCount());
        mapper.complete(key, System.currentTimeMillis());
        Assertions.assertTrue(l.await(30, TimeUnit.SECONDS));
        Assertions.assertEquals(0, mapper.pendingCount());
    }
    @Test
    public void timeoutRaw() throws InterruptedException {
        String key = RandomStringUtils.randomAlphanumeric(4);
        CountDownLatch l = new CountDownLatch(1);
        ListenableFuture<Long> f = mapper.acquire(key, Duration.ofMillis(1));
        f.addListener(new Runnable() {
            @Override
            public void run() {
                try {
                    f.get();
                } catch (Exception err) {
                    RequestReplyTimeout timeout = (RequestReplyTimeout) err.getCause();
                    logger.error(timeout.getMessage(), timeout);
                    l.countDown();
                }
            }
        }, MoreExecutors.directExecutor());
        Assertions.assertTrue(l.await(30, TimeUnit.SECONDS));

        Awaitility
                .waitAtMost(Duration.ofSeconds(1))
                .until(new Callable<Boolean>() {
                    @Override
                    public Boolean call() throws Exception {
                        return mapper.pendingCount() == 0;
                    }
                });
    }
    @Test
    public void timeoutFluent() throws InterruptedException {
        String key = RandomStringUtils.randomAlphanumeric(4);
        CountDownLatch l = new CountDownLatch(1);
        FluentFuture<Long> f = FluentFuture.from(mapper.acquire(key, Duration.ofMillis(1)));
        f.addCallback(new FutureCallback<Long>() {
            @Override
            public void onSuccess(Long result) {

            }
            @Override
            public void onFailure(Throwable t) {
                RequestReplyTimeout timeout = (RequestReplyTimeout) ExceptionUtils.getRootCause(t);
                logger.error(timeout.getMessage(), timeout);
                l.countDown();
            }
        }, mapper);
        Assertions.assertTrue(l.await(30, TimeUnit.SECONDS));

        Awaitility
                .waitAtMost(Duration.ofSeconds(1))
                .until(new Callable<Boolean>() {
                    @Override
                    public Boolean call() throws Exception {
                        return mapper.pendingCount() == 0;
                    }
                });
    }
    @Test
    public void exceptionally() throws InterruptedException {
        String key = RandomStringUtils.randomAlphanumeric(4);
        CountDownLatch l = new CountDownLatch(1);
        FluentFuture<Long> f = FluentFuture.from(mapper.acquire(key, Duration.ofMinutes(1)));
        f.addCallback(new FutureCallback<Long>() {
            @Override
            public void onSuccess(Long result) {

            }
            @Override
            public void onFailure(Throwable t) {
                l.countDown();
            }
        }, mapper);

        mapper.completeExceptionally(key, new IllegalStateException());
        Assertions.assertTrue(l.await(30, TimeUnit.SECONDS));

        Awaitility
                .waitAtMost(Duration.ofSeconds(1))
                .until(new Callable<Boolean>() {
                    @Override
                    public Boolean call() throws Exception {
                        return mapper.pendingCount() == 0;
                    }
                });
    }
}
